@@ -3,8 +3,8 @@
 # @Time    : 2021/5/10 17:01
 from pydantic import BaseModel
 
+from flask_openapi3 import Info, Tag
 from flask_openapi3 import OpenAPI
-from flask_openapi3.models import Info, Tag
 
 info = Info(title='book API', version='1.0.0')
 app = OpenAPI(__name__, info=info)
